@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
 our $DATE = '2016-06-17'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -233,13 +233,12 @@ sub __gen_table {
                             $maxw_bd = $w;
                         }
                     }
-                    #say "D:maxw_bd=<$maxw_bd> maxw_d=<$maxw_d> maxw_ad=<$maxw_ad>";
-                } else {
-                    $maxw = max(map {
-                        @$_ > $col ? length($_->[$col]) : 0
-                    } @$data);
                 }
 
+                $maxw = max(map {
+                    @$_ > $col ? length($_->[$col]) : 0
+                } @$data);
+
                 # do the alignment
                 for my $i (0..$#{$data}) {
                     my $row = $data->[$i];
@@ -265,18 +264,19 @@ sub __gen_table {
                                     $d , (' ' x ($maxw_d  - length($d ))),
                                     $ad, (' ' x ($maxw_ad - length($ad))),
                                 );
-                            } else {
-                                $cell .= (' ' x ($maxw_bd+$maxw_d+$maxw_ad - length($cell)));
                             }
+                            my $w = length($cell);
+                            $cell = (' ' x ($maxw - $w)) . $cell
+                                if $maxw > $w;
                         } elsif ($align eq 'right') {
-                            $cell .= (' ' x ($maxw - length($cell)));
+                            $cell = (' ' x ($maxw - length($cell))) . $cell;
                         } elsif ($align eq 'middle' || $align eq 'center') {
                             my $w = length($cell);
                             my $n = int(($maxw-$w)/2);
                             $cell = (' ' x $n) . $cell . (' ' x ($maxw-$w-$n));
                         } else {
                             # assumed left
-                            $cell = (' ' x ($maxw - length($cell))) . $cell;
+                            $cell .= (' ' x ($maxw - length($cell)));
 
                         }
                         $row->[$col] = $cell;
@@ -406,7 +406,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.16 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-06-17.
+This document describes version 0.17 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-06-17.
 
 =head1 SYNOPSIS
 
